@@ -5,17 +5,23 @@ cp("./docs/Project.toml", "./docs/src/assets/Project.toml", force = true)
 
 include("pages.jl")
 
-makedocs(sitename = "SciMLBase.jl",
+makedocs(
+    sitename = "SciMLBase.jl",
     authors = "Chris Rackauckas",
     modules = [SciMLBase, ModelingToolkit],
     clean = true, doctest = false, linkcheck = true,
     warnonly = [:docs_block, :missing_docs],
-    format = Documenter.HTML(assets = ["assets/favicon.ico"],
-        canonical = "https://docs.sciml.ai/SciMLBase/stable"),
+    format = Documenter.HTML(
+        assets = ["assets/favicon.ico"],
+        canonical = "https://docs.sciml.ai/SciMLBase/stable"
+    ),
     linkcheck_ignore = [
-        "https://www.sciencedirect.com/science/article/abs/pii/S0045782523007156"
+        "https://www.sciencedirect.com/science/article/abs/pii/S0045782523007156",
     ],
-    pages = pages)
+    pages = pages
+)
 
-deploydocs(repo = "github.com/SciML/SciMLBase.jl.git";
-    push_preview = true)
+deploydocs(
+    repo = "github.com/SciML/SciMLBase.jl.git";
+    push_preview = true
+)
