@@ -17,11 +17,11 @@ struct HermiteInterpolation{T1, T2, T3} <: AbstractDiffEqInterpolation
 end
 
 function HermiteInterpolation(t, u, du; sensitivitymode = false)
-    HermiteInterpolation(t, u, du, sensitivitymode)
+    return HermiteInterpolation(t, u, du, sensitivitymode)
 end
 
 function enable_interpolation_sensitivitymode(interp::HermiteInterpolation)
-    HermiteInterpolation(interp.t, interp.u, interp.du, true)
+    return HermiteInterpolation(interp.t, interp.u, interp.du, true)
 end
 
 """
@@ -34,11 +34,11 @@ struct LinearInterpolation{T1, T2} <: AbstractDiffEqInterpolation
 end
 
 function LinearInterpolation(t, u; sensitivitymode = false)
-    LinearInterpolation(t, u, sensitivitymode)
+    return LinearInterpolation(t, u, sensitivitymode)
 end
 
 function enable_interpolation_sensitivitymode(interp::LinearInterpolation)
-    LinearInterpolation(interp.t, interp.u, true)
+    return LinearInterpolation(interp.t, interp.u, true)
 end
 
 """
@@ -51,11 +51,11 @@ struct ConstantInterpolation{T1, T2} <: AbstractDiffEqInterpolation
 end
 
 function ConstantInterpolation(t, u; sensitivitymode = false)
-    ConstantInterpolation(t, u, sensitivitymode)
+    return ConstantInterpolation(t, u, sensitivitymode)
 end
 
 function enable_interpolation_sensitivitymode(interp::ConstantInterpolation)
-    ConstantInterpolation(interp.t, interp.u, true)
+    return ConstantInterpolation(interp.t, interp.u, true)
 end
 
 interp_summary(::AbstractDiffEqInterpolation) = "Unknown"
@@ -66,36 +66,38 @@ interp_summary(::Nothing) = "No interpolation"
 interp_summary(sol::AbstractSciMLSolution) = interp_summary(sol.interp)
 
 const SENSITIVITY_INTERP_MESSAGE = """
-                                   Standard interpolation is disabled due to sensitivity analysis being
-                                   used for the gradients. Only linear and constant interpolations are
-                                   compatible with non-AD sensitivity analysis calculations. Either
-                                   utilize tooling like saveat to avoid post-solution interpolation, use
-                                   the keyword argument dense=false for linear or constant interpolations,
-                                   or use the keyword argument sensealg=SensitivityADPassThrough() to revert
-                                   to AD-based derivatives.
-                                   """
+Standard interpolation is disabled due to sensitivity analysis being
+used for the gradients. Only linear and constant interpolations are
+compatible with non-AD sensitivity analysis calculations. Either
+utilize tooling like saveat to avoid post-solution interpolation, use
+the keyword argument dense=false for linear or constant interpolations,
+or use the keyword argument sensealg=SensitivityADPassThrough() to revert
+to AD-based derivatives.
+"""
 
 function (id::HermiteInterpolation)(tvals, idxs, deriv, p, continuity::Symbol = :left)
-    interpolation(tvals, id, idxs, deriv, p, continuity)
+    return interpolation(tvals, id, idxs, deriv, p, continuity)
 end
 function (id::HermiteInterpolation)(val, tvals, idxs, deriv, p, continuity::Symbol = :left)
-    interpolation!(val, tvals, id, idxs, deriv, p, continuity)
+    return interpolation!(val, tvals, id, idxs, deriv, p, continuity)
 end
 function (id::LinearInterpolation)(tvals, idxs, deriv, p, continuity::Symbol = :left)
-    interpolation(tvals, id, idxs, deriv, p, continuity)
+    return interpolation(tvals, id, idxs, deriv, p, continuity)
 end
 function (id::LinearInterpolation)(val, tvals, idxs, deriv, p, continuity::Symbol = :left)
-    interpolation!(val, tvals, id, idxs, deriv, p, continuity)
+    return interpolation!(val, tvals, id, idxs, deriv, p, continuity)
 end
 function (id::ConstantInterpolation)(tvals, idxs, deriv, p, continuity::Symbol = :left)
-    interpolation(tvals, id, idxs, deriv, p, continuity)
+    return interpolation(tvals, id, idxs, deriv, p, continuity)
 end
 function (id::ConstantInterpolation)(val, tvals, idxs, deriv, p, continuity::Symbol = :left)
-    interpolation!(val, tvals, id, idxs, deriv, p, continuity)
+    return interpolation!(val, tvals, id, idxs, deriv, p, continuity)
 end
 
-@inline function interpolation(tvals, id::I, idxs, deriv::D, p,
-        continuity::Symbol = :left) where {I, D}
+@inline function interpolation(
+        tvals, id::I, idxs, deriv::D, p,
+        continuity::Symbol = :left
+    ) where {I, D}
     t = id.t
     u = id.u
     id isa HermiteInterpolation && (du = id.du)
@@ -140,14 +142,16 @@ end
             Θ = (tval - t[i - 1]) / dt
             idxs_internal = idxs
             if id isa HermiteInterpolation
-                vals[j] = interpolant(Θ, id, dt, u[i - 1], u[i], du[i - 1], du[i],
-                    idxs_internal, deriv)
+                vals[j] = interpolant(
+                    Θ, id, dt, u[i - 1], u[i], du[i - 1], du[i],
+                    idxs_internal, deriv
+                )
             else
                 vals[j] = interpolant(Θ, id, dt, u[i - 1], u[i], idxs_internal, deriv)
             end
         end
     end
-    DiffEqArray(vals, tvals)
+    return DiffEqArray(vals, tvals)
 end
 
 """
@@ -156,8 +160,10 @@ $(SIGNATURES)
 Get the value at tvals where the solution is known at the
 times t (sorted), with values u and derivatives ks
 """
-@inline function interpolation!(vals, tvals, id::I, idxs, deriv::D, p,
-        continuity::Symbol = :left) where {I, D}
+@inline function interpolation!(
+        vals, tvals, id::I, idxs, deriv::D, p,
+        continuity::Symbol = :left
+    ) where {I, D}
     t = id.t
     u = id.u
     id isa HermiteInterpolation && (du = id.du)
@@ -196,21 +202,26 @@ times t (sorted), with values u and derivatives ks
             idxs_internal = idxs
             if eltype(u) <: Union{AbstractArray, ArrayPartition}
                 if id isa HermiteInterpolation
-                    interpolant!(vals[j], Θ, id, dt, u[i - 1], u[i], du[i - 1], du[i],
-                        idxs_internal, deriv)
+                    interpolant!(
+                        vals[j], Θ, id, dt, u[i - 1], u[i], du[i - 1], du[i],
+                        idxs_internal, deriv
+                    )
                 else
                     interpolant!(vals[j], Θ, id, dt, u[i - 1], u[i], idxs_internal, deriv)
                 end
             else
                 if id isa HermiteInterpolation
-                    vals[j] = interpolant(Θ, id, dt, u[i - 1], u[i], du[i - 1], du[i],
-                        idxs_internal, deriv)
+                    vals[j] = interpolant(
+                        Θ, id, dt, u[i - 1], u[i], du[i - 1], du[i],
+                        idxs_internal, deriv
+                    )
                 else
                     vals[j] = interpolant(Θ, id, dt, u[i - 1], u[i], idxs_internal, deriv)
                 end
             end
         end
     end
+    return
 end
 
 """
@@ -219,8 +230,10 @@ $(SIGNATURES)
 Get the value at tval where the solution is known at the
 times t (sorted), with values u and derivatives ks
 """
-@inline function interpolation(tval::Number, id::I, idxs, deriv::D, p,
-        continuity::Symbol = :left) where {I, D}
+@inline function interpolation(
+        tval::Number, id::I, idxs, deriv::D, p,
+        continuity::Symbol = :left
+    ) where {I, D}
     t = id.t
     u = id.u
     id isa HermiteInterpolation && (du = id.du)
@@ -254,13 +267,15 @@ times t (sorted), with values u and derivatives ks
         Θ = (tval - t[i - 1]) / dt
         idxs_internal = idxs
         if id isa HermiteInterpolation
-            val = interpolant(Θ, id, dt, u[i - 1], u[i], du[i - 1], du[i], idxs_internal,
-                deriv)
+            val = interpolant(
+                Θ, id, dt, u[i - 1], u[i], du[i - 1], du[i], idxs_internal,
+                deriv
+            )
         else
             val = interpolant(Θ, id, dt, u[i - 1], u[i], idxs_internal, deriv)
         end
     end
-    val
+    return val
 end
 
 """
@@ -269,8 +284,10 @@ $(SIGNATURES)
 Get the value at tval where the solution is known at the
 times t (sorted), with values u and derivatives ks
 """
-@inline function interpolation!(out, tval::Number, id::I, idxs, deriv::D, p,
-        continuity::Symbol = :left) where {I, D}
+@inline function interpolation!(
+        out, tval::Number, id::I, idxs, deriv::D, p,
+        continuity::Symbol = :left
+    ) where {I, D}
     t = id.t
     u = id.u
     id isa HermiteInterpolation && (du = id.du)
@@ -284,7 +301,7 @@ times t (sorted), with values u and derivatives ks
     @inbounds i = searchsortedfirst(t, tval, rev = tdir < 0) # It's in the interval t[i-1] to t[i]
     avoid_constant_ends = deriv != Val{0} #|| tval isa ForwardDiff.Dual
     avoid_constant_ends && i == 1 && (i += 1)
-    if !avoid_constant_ends && t[i] == tval
+    return if !avoid_constant_ends && t[i] == tval
         lasti = lastindex(t)
         k = continuity == :right && i + 1 <= lasti && t[i + 1] == tval ? i + 1 : i
         if idxs === nothing
@@ -304,8 +321,10 @@ times t (sorted), with values u and derivatives ks
         Θ = (tval - t[i - 1]) / dt
         idxs_internal = idxs
         if id isa HermiteInterpolation
-            interpolant!(out, Θ, id, dt, u[i - 1], u[i], du[i - 1], du[i], idxs_internal,
-                deriv)
+            interpolant!(
+                out, Θ, id, dt, u[i - 1], u[i], du[i - 1], du[i], idxs_internal,
+                deriv
+            )
         else
             interpolant!(out, Θ, id, dt, u[i - 1], u[i], idxs_internal, deriv)
         end
@@ -314,7 +333,8 @@ end
 
 @inline function interpolant(
         Θ, id::AbstractDiffEqInterpolation, dt, y₀, y₁, dy₀, dy₁, idxs,
-        ::Type{Val{D}}) where {D}
+        ::Type{Val{D}}
+    ) where {D}
     error("$(string(typeof(id))) for $(D)th order not implemented")
 end
 ##################### Hermite Interpolants
@@ -324,90 +344,126 @@ Hairer Norsett Wanner Solving Ordinary Differential Equations I - Nonstiff Probl
 
 Hermite Interpolation
 """
-@inline function interpolant(Θ, id::HermiteInterpolation, dt, y₀, y₁, dy₀, dy₁, idxs,
-        T::Type{Val{0}})
+@inline function interpolant(
+        Θ, id::HermiteInterpolation, dt, y₀, y₁, dy₀, dy₁, idxs,
+        T::Type{Val{0}}
+    )
     if idxs === nothing
         out = @. (1 - Θ) * y₀ + Θ * y₁ +
-                 Θ * (Θ - 1) * ((1 - 2Θ) * (y₁ - y₀) + (Θ - 1) * dt * dy₀ + Θ * dt * dy₁)
+            Θ * (Θ - 1) * ((1 - 2Θ) * (y₁ - y₀) + (Θ - 1) * dt * dy₀ + Θ * dt * dy₁)
     elseif idxs isa Number
         out = (1 - Θ) * y₀[idxs] + Θ * y₁[idxs] +
-              Θ * (Θ - 1) *
-              ((1 - 2Θ) * (y₁[idxs] - y₀[idxs]) +
-               (Θ - 1) * dt * dy₀[idxs] + Θ * dt * dy₁[idxs])
+            Θ * (Θ - 1) *
+            (
+            (1 - 2Θ) * (y₁[idxs] - y₀[idxs]) +
+                (Θ - 1) * dt * dy₀[idxs] + Θ * dt * dy₁[idxs]
+        )
     else
         out = similar(y₀, axes(idxs))
         @views @. out = (1 - Θ) * y₀[idxs] + Θ * y₁[idxs] +
-                        Θ * (Θ - 1) *
-                        ((1 - 2Θ) * (y₁[idxs] - y₀[idxs]) +
-                         (Θ - 1) * dt * dy₀[idxs] + Θ * dt * dy₁[idxs])
+            Θ * (Θ - 1) *
+            (
+            (1 - 2Θ) * (y₁[idxs] - y₀[idxs]) +
+                (Θ - 1) * dt * dy₀[idxs] + Θ * dt * dy₁[idxs]
+        )
     end
-    out
+    return out
 end
 
 """
 Hermite Interpolation
 """
-@inline function interpolant(Θ, id::HermiteInterpolation, dt, y₀, y₁, dy₀, dy₁, idxs,
-        T::Type{Val{1}})
+@inline function interpolant(
+        Θ, id::HermiteInterpolation, dt, y₀, y₁, dy₀, dy₁, idxs,
+        T::Type{Val{1}}
+    )
     if idxs === nothing
         out = @. dy₀ +
-                 Θ * (-4 * dt * dy₀ - 2 * dt * dy₁ - 6 * y₀ +
-                  Θ * (3 * dt * dy₀ + 3 * dt * dy₁ + 6 * y₀ - 6 * y₁) + 6 * y₁) / dt
+            Θ * (
+            -4 * dt * dy₀ - 2 * dt * dy₁ - 6 * y₀ +
+                Θ * (3 * dt * dy₀ + 3 * dt * dy₁ + 6 * y₀ - 6 * y₁) + 6 * y₁
+        ) / dt
     elseif idxs isa Number
         out = dy₀[idxs] +
-              Θ * (-4 * dt * dy₀[idxs] -
-               2 * dt * dy₁[idxs] - 6 * y₀[idxs] +
-               Θ * (3 * dt * dy₀[idxs] + 3 * dt * dy₁[idxs] +
-                    6 * y₀[idxs] - 6 * y₁[idxs]) + 6 * y₁[idxs]) / dt
+            Θ * (
+            -4 * dt * dy₀[idxs] -
+                2 * dt * dy₁[idxs] - 6 * y₀[idxs] +
+                Θ * (
+                3 * dt * dy₀[idxs] + 3 * dt * dy₁[idxs] +
+                    6 * y₀[idxs] - 6 * y₁[idxs]
+            ) + 6 * y₁[idxs]
+        ) / dt
     else
         out = similar(y₀, axes(idxs))
         @views @. out = dy₀[idxs] +
-                        Θ * (-4 * dt * dy₀[idxs] -
-                         2 * dt * dy₁[idxs] - 6 * y₀[idxs] +
-                         Θ * (3 * dt * dy₀[idxs] + 3 * dt * dy₁[idxs] +
-                          6 * y₀[idxs] - 6 * y₁[idxs]) + 6 * y₁[idxs]) / dt
+            Θ * (
+            -4 * dt * dy₀[idxs] -
+                2 * dt * dy₁[idxs] - 6 * y₀[idxs] +
+                Θ * (
+                3 * dt * dy₀[idxs] + 3 * dt * dy₁[idxs] +
+                    6 * y₀[idxs] - 6 * y₁[idxs]
+            ) + 6 * y₁[idxs]
+        ) / dt
     end
-    out
+    return out
 end
 
 """
 Hermite Interpolation
 """
-@inline function interpolant(Θ, id::HermiteInterpolation, dt, y₀, y₁, dy₀, dy₁, idxs,
-        T::Type{Val{2}})
+@inline function interpolant(
+        Θ, id::HermiteInterpolation, dt, y₀, y₁, dy₀, dy₁, idxs,
+        T::Type{Val{2}}
+    )
     if idxs === nothing
-        out = @. (-4 * dt * dy₀ - 2 * dt * dy₁ - 6 * y₀ +
-                  Θ * (6 * dt * dy₀ + 6 * dt * dy₁ + 12 * y₀ - 12 * y₁) + 6 * y₁) /
-                 (dt * dt)
+        out = @. (
+            -4 * dt * dy₀ - 2 * dt * dy₁ - 6 * y₀ +
+                Θ * (6 * dt * dy₀ + 6 * dt * dy₁ + 12 * y₀ - 12 * y₁) + 6 * y₁
+        ) /
+            (dt * dt)
     elseif idxs isa Number
-        out = (-4 * dt * dy₀[idxs] - 2 * dt * dy₁[idxs] - 6 * y₀[idxs] +
-               Θ * (6 * dt * dy₀[idxs] + 6 * dt * dy₁[idxs] + 12 * y₀[idxs] -
-                12 * y₁[idxs]) + 6 * y₁[idxs]) / (dt * dt)
+        out = (
+            -4 * dt * dy₀[idxs] - 2 * dt * dy₁[idxs] - 6 * y₀[idxs] +
+                Θ * (
+                6 * dt * dy₀[idxs] + 6 * dt * dy₁[idxs] + 12 * y₀[idxs] -
+                    12 * y₁[idxs]
+            ) + 6 * y₁[idxs]
+        ) / (dt * dt)
     else
         out = similar(y₀, axes(idxs))
-        @views @. out = (-4 * dt * dy₀[idxs] - 2 * dt * dy₁[idxs] - 6 * y₀[idxs] +
-                         Θ * (6 * dt * dy₀[idxs] + 6 * dt * dy₁[idxs] + 12 * y₀[idxs] -
-                          12 * y₁[idxs]) + 6 * y₁[idxs]) / (dt * dt)
+        @views @. out = (
+            -4 * dt * dy₀[idxs] - 2 * dt * dy₁[idxs] - 6 * y₀[idxs] +
+                Θ * (
+                6 * dt * dy₀[idxs] + 6 * dt * dy₁[idxs] + 12 * y₀[idxs] -
+                    12 * y₁[idxs]
+            ) + 6 * y₁[idxs]
+        ) / (dt * dt)
     end
-    out
+    return out
 end
 
 """
 Hermite Interpolation
 """
-@inline function interpolant(Θ, id::HermiteInterpolation, dt, y₀, y₁, dy₀, dy₁, idxs,
-        T::Type{Val{3}})
+@inline function interpolant(
+        Θ, id::HermiteInterpolation, dt, y₀, y₁, dy₀, dy₁, idxs,
+        T::Type{Val{3}}
+    )
     if idxs === nothing
         out = @. (6 * dt * dy₀ + 6 * dt * dy₁ + 12 * y₀ - 12 * y₁) / (dt * dt * dt)
     elseif idxs isa Number
-        out = (6 * dt * dy₀[idxs] + 6 * dt * dy₁[idxs] +
-               12 * y₀[idxs] - 12 * y₁[idxs]) / (dt * dt * dt)
+        out = (
+            6 * dt * dy₀[idxs] + 6 * dt * dy₁[idxs] +
+                12 * y₀[idxs] - 12 * y₁[idxs]
+        ) / (dt * dt * dt)
     else
         out = similar(y₀, axes(idxs))
-        @views @. out = (6 * dt * dy₀[idxs] + 6 * dt * dy₁[idxs] +
-                         12 * y₀[idxs] - 12 * y₁[idxs]) / (dt * dt * dt)
+        @views @. out = (
+            6 * dt * dy₀[idxs] + 6 * dt * dy₁[idxs] +
+                12 * y₀[idxs] - 12 * y₁[idxs]
+        ) / (dt * dt * dt)
     end
-    out
+    return out
 end
 
 """
@@ -415,81 +471,111 @@ Hairer Norsett Wanner Solving Ordinary Differential Euations I - Nonstiff Proble
 
 Hermite Interpolation
 """
-@inline function interpolant!(out, Θ, id::HermiteInterpolation, dt, y₀, y₁, dy₀, dy₁, idxs,
-        T::Type{Val{0}})
+@inline function interpolant!(
+        out, Θ, id::HermiteInterpolation, dt, y₀, y₁, dy₀, dy₁, idxs,
+        T::Type{Val{0}}
+    )
     if out === nothing
         return (1 - Θ) * y₀[idxs] + Θ * y₁[idxs] +
-               Θ * (Θ - 1) *
-               ((1 - 2Θ) * (y₁[idxs] - y₀[idxs]) + (Θ - 1) * dt * dy₀[idxs] +
-                Θ * dt * dy₁[idxs])
+            Θ * (Θ - 1) *
+            (
+            (1 - 2Θ) * (y₁[idxs] - y₀[idxs]) + (Θ - 1) * dt * dy₀[idxs] +
+                Θ * dt * dy₁[idxs]
+        )
     elseif idxs === nothing
         @. out = (1 - Θ) * y₀ + Θ * y₁ +
-                 Θ * (Θ - 1) * ((1 - 2Θ) * (y₁ - y₀) + (Θ - 1) * dt * dy₀ + Θ * dt * dy₁)
+            Θ * (Θ - 1) * ((1 - 2Θ) * (y₁ - y₀) + (Θ - 1) * dt * dy₀ + Θ * dt * dy₁)
     else
         @views @. out = (1 - Θ) * y₀[idxs] + Θ * y₁[idxs] +
-                        Θ * (Θ - 1) *
-                        ((1 - 2Θ) * (y₁[idxs] - y₀[idxs]) + (Θ - 1) * dt * dy₀[idxs] +
-                         Θ * dt * dy₁[idxs])
+            Θ * (Θ - 1) *
+            (
+            (1 - 2Θ) * (y₁[idxs] - y₀[idxs]) + (Θ - 1) * dt * dy₀[idxs] +
+                Θ * dt * dy₁[idxs]
+        )
     end
 end
 
 """
 Hermite Interpolation
 """
-@inline function interpolant!(out, Θ, id::HermiteInterpolation, dt, y₀, y₁, dy₀, dy₁, idxs,
-        T::Type{Val{1}})
+@inline function interpolant!(
+        out, Θ, id::HermiteInterpolation, dt, y₀, y₁, dy₀, dy₁, idxs,
+        T::Type{Val{1}}
+    )
     if out === nothing
         return dy₀[idxs] +
-               Θ * (-4 * dt * dy₀[idxs] - 2 * dt * dy₁[idxs] - 6 * y₀[idxs] +
+            Θ * (
+            -4 * dt * dy₀[idxs] - 2 * dt * dy₁[idxs] - 6 * y₀[idxs] +
                 Θ *
                 (3 * dt * dy₀[idxs] + 3 * dt * dy₁[idxs] + 6 * y₀[idxs] - 6 * y₁[idxs]) +
-                6 * y₁[idxs]) / dt
+                6 * y₁[idxs]
+        ) / dt
     elseif idxs === nothing
         @. out = dy₀ +
-                 Θ * (-4 * dt * dy₀ - 2 * dt * dy₁ - 6 * y₀ +
-                  Θ * (3 * dt * dy₀ + 3 * dt * dy₁ + 6 * y₀ - 6 * y₁) + 6 * y₁) / dt
+            Θ * (
+            -4 * dt * dy₀ - 2 * dt * dy₁ - 6 * y₀ +
+                Θ * (3 * dt * dy₀ + 3 * dt * dy₁ + 6 * y₀ - 6 * y₁) + 6 * y₁
+        ) / dt
     else
         @views @. out = dy₀[idxs] +
-                        Θ * (-4 * dt * dy₀[idxs] - 2 * dt * dy₁[idxs] - 6 * y₀[idxs] +
-                         Θ * (3 * dt * dy₀[idxs] + 3 * dt * dy₁[idxs] + 6 * y₀[idxs] -
-                          6 * y₁[idxs]) + 6 * y₁[idxs]) / dt
+            Θ * (
+            -4 * dt * dy₀[idxs] - 2 * dt * dy₁[idxs] - 6 * y₀[idxs] +
+                Θ * (
+                3 * dt * dy₀[idxs] + 3 * dt * dy₁[idxs] + 6 * y₀[idxs] -
+                    6 * y₁[idxs]
+            ) + 6 * y₁[idxs]
+        ) / dt
     end
 end
 
 """
 Hermite Interpolation
 """
-@inline function interpolant!(out, Θ, id::HermiteInterpolation, dt, y₀, y₁, dy₀, dy₁, idxs,
-        T::Type{Val{2}})
+@inline function interpolant!(
+        out, Θ, id::HermiteInterpolation, dt, y₀, y₁, dy₀, dy₁, idxs,
+        T::Type{Val{2}}
+    )
     if out === nothing
-        return (-4 * dt * dy₀[idxs] - 2 * dt * dy₁[idxs] - 6 * y₀[idxs] +
+        return (
+            -4 * dt * dy₀[idxs] - 2 * dt * dy₁[idxs] - 6 * y₀[idxs] +
                 Θ *
                 (6 * dt * dy₀[idxs] + 6 * dt * dy₁[idxs] + 12 * y₀[idxs] - 12 * y₁[idxs]) +
-                6 * y₁[idxs]) / (dt * dt)
+                6 * y₁[idxs]
+        ) / (dt * dt)
     elseif idxs === nothing
-        @. out = (-4 * dt * dy₀ - 2 * dt * dy₁ - 6 * y₀ +
-                  Θ * (6 * dt * dy₀ + 6 * dt * dy₁ + 12 * y₀ - 12 * y₁) + 6 * y₁) /
-                 (dt * dt)
+        @. out = (
+            -4 * dt * dy₀ - 2 * dt * dy₁ - 6 * y₀ +
+                Θ * (6 * dt * dy₀ + 6 * dt * dy₁ + 12 * y₀ - 12 * y₁) + 6 * y₁
+        ) /
+            (dt * dt)
     else
-        @views @. out = (-4 * dt * dy₀[idxs] - 2 * dt * dy₁[idxs] - 6 * y₀[idxs] +
-                         Θ * (6 * dt * dy₀[idxs] + 6 * dt * dy₁[idxs] + 12 * y₀[idxs] -
-                          12 * y₁[idxs]) + 6 * y₁[idxs]) / (dt * dt)
+        @views @. out = (
+            -4 * dt * dy₀[idxs] - 2 * dt * dy₁[idxs] - 6 * y₀[idxs] +
+                Θ * (
+                6 * dt * dy₀[idxs] + 6 * dt * dy₁[idxs] + 12 * y₀[idxs] -
+                    12 * y₁[idxs]
+            ) + 6 * y₁[idxs]
+        ) / (dt * dt)
     end
 end
 
 """
 Hermite Interpolation
 """
-@inline function interpolant!(out, Θ, id::HermiteInterpolation, dt, y₀, y₁, dy₀, dy₁, idxs,
-        T::Type{Val{3}})
+@inline function interpolant!(
+        out, Θ, id::HermiteInterpolation, dt, y₀, y₁, dy₀, dy₁, idxs,
+        T::Type{Val{3}}
+    )
     if out === nothing
         return (6 * dt * dy₀[idxs] + 6 * dt * dy₁[idxs] + 12 * y₀[idxs] - 12 * y₁[idxs]) /
-               (dt * dt * dt)
+            (dt * dt * dt)
     elseif idxs === nothing
         @. out = (6 * dt * dy₀ + 6 * dt * dy₁ + 12 * y₀ - 12 * y₁) / (dt * dt * dt)
     else
-        @views @. out = (6 * dt * dy₀[idxs] + 6 * dt * dy₁[idxs] + 12 * y₀[idxs] -
-                         12 * y₁[idxs]) / (dt * dt * dt)
+        @views @. out = (
+            6 * dt * dy₀[idxs] + 6 * dt * dy₁[idxs] + 12 * y₀[idxs] -
+                12 * y₁[idxs]
+        ) / (dt * dt * dt)
     end
 end
 
@@ -508,7 +594,7 @@ Linear Interpolation
         out = similar(y₀, axes(idxs))
         @views @. out = Θm1 * y₀[idxs] + Θ * y₁[idxs]
     end
-    out
+    return out
 end
 
 @inline function interpolant(Θ, id::LinearInterpolation, dt, y₀, y₁, idxs, T::Type{Val{1}})
@@ -520,14 +606,16 @@ end
         out = similar(y₀, axes(idxs))
         @views @. out = (y₁[idxs] - y₀[idxs]) / dt
     end
-    out
+    return out
 end
 
 """
 Linear Interpolation
 """
-@inline function interpolant!(out, Θ, id::LinearInterpolation, dt, y₀, y₁, idxs,
-        T::Type{Val{0}})
+@inline function interpolant!(
+        out, Θ, id::LinearInterpolation, dt, y₀, y₁, idxs,
+        T::Type{Val{0}}
+    )
     Θm1 = (1 - Θ)
     if out === nothing
         return Θm1 * y₀[idxs] + Θ * y₁[idxs]
@@ -541,8 +629,10 @@ end
 """
 Linear Interpolation
 """
-@inline function interpolant!(out, Θ, id::LinearInterpolation, dt, y₀, y₁, idxs,
-        T::Type{Val{1}})
+@inline function interpolant!(
+        out, Θ, id::LinearInterpolation, dt, y₀, y₁, idxs,
+        T::Type{Val{1}}
+    )
     if out === nothing
         return (y₁[idxs] - y₀[idxs]) / dt
     elseif idxs === nothing
@@ -557,8 +647,10 @@ end
 """
 Constant Interpolation
 """
-@inline function interpolant(Θ, id::ConstantInterpolation, dt, y₀, y₁, idxs,
-        T::Type{Val{0}})
+@inline function interpolant(
+        Θ, id::ConstantInterpolation, dt, y₀, y₁, idxs,
+        T::Type{Val{0}}
+    )
     if idxs === nothing
         out = @. y₀
     elseif idxs isa Number
@@ -567,11 +659,13 @@ Constant Interpolation
         out = similar(y₀, axes(idxs))
         @views @. out = y₀[idxs]
     end
-    out
+    return out
 end
 
-@inline function interpolant(Θ, id::ConstantInterpolation, dt, y₀, y₁, idxs,
-        T::Type{Val{1}})
+@inline function interpolant(
+        Θ, id::ConstantInterpolation, dt, y₀, y₁, idxs,
+        T::Type{Val{1}}
+    )
     if idxs === nothing
         out = zeros(eltype(y₀), length(y₀))
     elseif idxs isa Number
@@ -580,14 +674,16 @@ end
         out = similar(y₀, axes(idxs))
         @views @. out = 0
     end
-    out
+    return out
 end
 
 """
 Constant Interpolation
 """
-@inline function interpolant!(out, Θ, id::ConstantInterpolation, dt, y₀, y₁, idxs,
-        T::Type{Val{0}})
+@inline function interpolant!(
+        out, Θ, id::ConstantInterpolation, dt, y₀, y₁, idxs,
+        T::Type{Val{0}}
+    )
     if out === nothing
         return y₀[idxs]
     elseif idxs === nothing
@@ -600,8 +696,10 @@ end
 """
 Constant Interpolation
 """
-@inline function interpolant!(out, Θ, id::ConstantInterpolation, dt, y₀, y₁, idxs,
-        T::Type{Val{1}})
+@inline function interpolant!(
+        out, Θ, id::ConstantInterpolation, dt, y₀, y₁, idxs,
+        T::Type{Val{1}}
+    )
     if out === nothing
         return zeros(eltype(y₀), length(idxs))
     else
