@@ -2,29 +2,35 @@
 $(TYPEDEF)
 """
 struct AnalyticalProblem{uType, tType, isinplace, P, F, K} <:
-       AbstractAnalyticalProblem{uType, tType, isinplace}
+    AbstractAnalyticalProblem{uType, tType, isinplace}
     f::F
     u0::uType
     tspan::tType
     p::P
     kwargs::K
-    @add_kwonly function AnalyticalProblem{iip}(f, u0, tspan, p = NullParameters();
-            kwargs...) where {iip}
+    @add_kwonly function AnalyticalProblem{iip}(
+            f, u0, tspan, p = NullParameters();
+            kwargs...
+        ) where {iip}
         _u0 = prepare_initial_state(u0)
         _tspan = promote_tspan(tspan)
         warn_paramtype(p)
-        new{typeof(_u0), typeof(_tspan), iip, typeof(p),
-            typeof(f), typeof(kwargs)}(f,
+        new{
+            typeof(_u0), typeof(_tspan), iip, typeof(p),
+            typeof(f), typeof(kwargs),
+        }(
+            f,
             _u0,
             _tspan,
             p,
-            kwargs)
+            kwargs
+        )
     end
 end
 
 function AnalyticalProblem(f, u0, tspan, p = NullParameters(); kwargs...)
     iip = isinplace(f, 4)
-    AnalyticalProblem{iip}(f, u0, tspan, p; kwargs...)
+    return AnalyticalProblem{iip}(f, u0, tspan, p; kwargs...)
 end
 
 export AnalyticalProblem, AbstractAnalyticalProblem
@@ -55,8 +61,9 @@ struct AnalyticalAliasSpecifier <: AbstractAliasSpecifier
 
     function AnalyticalAliasSpecifier(;
             alias_p = nothing, alias_f = nothing, alias_u0 = nothing,
-            alias_du0 = nothing, alias_tstops = nothing, alias = nothing)
-        if alias == true
+            alias_du0 = nothing, alias_tstops = nothing, alias = nothing
+        )
+        return if alias == true
             new(true, true, true, true, true)
         elseif alias == false
             new(false, false, false, false, false)
