@@ -320,6 +320,17 @@ function isinplace(
     return iip
 end
 
+# Determine in-place status for FunctionWrappersWrapper by inspecting the return types
+# of the wrapped FunctionWrapper variants. An IIP wrapper has all variants returning
+# Nothing (the mutating convention), while OOP wrappers return non-Nothing types.
+function isinplace(f::FunctionWrappersWrappers.FunctionWrappersWrapper{FW}, inplace_param_number,
+        fname = "f", iip_preferred = true;
+        has_two_dispatches = false, isoptimization = false,
+        outofplace_param_number = inplace_param_number - 1) where {FW}
+    # Extract return types from FunctionWrapper{R,A} type parameters in the tuple
+    return all(T -> T.parameters[1] === Nothing, FW.parameters)
+end
+
 """
     @CSI_str cmd
 
