@@ -22,9 +22,9 @@ using ModelingToolkit: t_nounits as t, D_nounits as D
     ], t
 )
 
-prob1 = ODEProblem(sys1, [1.0, 1.0], (0.0, 1.0))
-prob2 = ODEProblem(sys2, [2.0, 2.0], (0.0, 1.0))
-prob3 = ODEProblem(sys3, [3.0, 3.0], (0.0, 1.0))
+prob1 = ODEProblem(sys1, [x => 1.0, y => 1.0], (0.0, 1.0))
+prob2 = ODEProblem(sys2, [x => 2.0, y => 2.0], (0.0, 1.0))
+prob3 = ODEProblem(sys3, [x => 3.0, y => 3.0], (0.0, 1.0))
 
 # test that when passing a vector of problems, trajectories and the prob_func are chosen appropriately
 ensemble_prob = EnsembleProblem([prob1, prob2, prob3])
