@@ -18,7 +18,7 @@ function activate_python_env()
 end
 
 @time begin
-    if GROUP == "QA" || GROUP == "All"
+    if GROUP == "QA"
         @time @safetestset "Aqua" begin
             include("aqua.jl")
         end
@@ -95,10 +95,8 @@ end
         @time @safetestset "Integer idxs" begin
             include("downstream/integer_idxs.jl")
         end
-        if VERSION < v"1.12" # Zygote is incredibly broken on 1.12
-            @time @safetestset "Autodiff Remake" begin
-                include("downstream/remake_autodiff.jl")
-            end
+        @time @safetestset "Autodiff Remake" begin
+            include("downstream/remake_autodiff.jl")
         end
         @time @safetestset "Partial Functions" begin
             include("downstream/partial_functions.jl")
@@ -136,10 +134,8 @@ end
         @time @safetestset "Problem Indexing" begin
             include("downstream/problem_interface.jl")
         end
-        if VERSION < v"1.12" # Zygote is incredibly broken on 1.12
-            @time @safetestset "Adjoints" begin
-                include("downstream/adjoints.jl")
-            end
+        @time @safetestset "Adjoints" begin
+            include("downstream/adjoints.jl")
         end
         @time @safetestset "ModelingToolkit Remake" begin
             include("downstream/modelingtoolkit_remake.jl")
